import uuid

import click

from gcs_cli.helpers import requires_login
from gcs_cli.parsing import auth_policy_id_arg, globus_command
from gcs_cli.sdk_client.auth_client import MissingConsent
from gcs_cli.services.auth import get_client


@globus_command(
    "delete",
    short_help="Delete the authentication policy",
    disable_options=["explicit_host", "format"],
)
@requires_login
@auth_policy_id_arg
def auth_policy_delete(auth_policy_id: uuid.UUID) -> None:
    """
    Delete the authentication policy.
    """
    client = get_client()
    try:
        client.delete_policy(auth_policy_id)
    except MissingConsent as e:
        raise click.ClickException(
            "Missing consent for the policy API. Please run the following command:\n"
            f"    globus-connect-server session consent {e.scope}"
        )
    click.echo(f"Deleted authentication policy {auth_policy_id}")
