from typing import Any, Dict, Iterable, Optional

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    globus_command,
    google_cloud_storage_options,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import GoogleCloudStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import GOOGLE_CLOUD_STORAGE_CONNECTOR_ID


@globus_command("google-cloud-storage")
@storage_gateway_create_and_update_params(create=True)
@google_cloud_storage_options(create=True)
@make_create_command
def google_cloud_storage_create(
    *,
    google_client_id: Optional[str],
    google_client_secret: Optional[str],
    google_allow_any_account: Optional[bool],
    google_service_account_key: Optional[Dict[str, Any]],
    bucket: Optional[Iterable[str]],
    google_cloud_storage_project: Optional[Iterable[str]],
    **kwargs: Any
) -> StorageGatewayDocument:
    """Create a new Google Cloud Storage Storage Gateway"""
    if google_service_account_key:
        google_client_id = "ignored"
        google_client_secret = "ignored"

    policies = GoogleCloudStoragePolicies(
        client_id=google_client_id,
        secret=google_client_secret,
        service_account_key=google_service_account_key,
        buckets=bucket,
        projects=google_cloud_storage_project,
        allow_any_account=google_allow_any_account,
    )
    return StorageGatewayDocument(
        connector_id=GOOGLE_CLOUD_STORAGE_CONNECTOR_ID, policies=policies, **kwargs
    )
