from __future__ import annotations

from oauth2client import GOOGLE_TOKEN_URI

from globus.manager.constants import ConfigurationObjectTag

from .oidc_user_credential import OIDCUserCredential


class GoogleDriveUserCredential(OIDCUserCredential):
    POLICY_DATA_TYPE = "google_drive_user_credential_policies#1.0.0"
    POLICY_DATA_TYPES = [POLICY_DATA_TYPE]
    CONNECTOR_ID = "976cf0cf-78c3-4aab-82d2-7c16adbcc281"

    __mapper_args__ = {
        "polymorphic_identity": (
            ConfigurationObjectTag.USER_CREDENTIAL.name + CONNECTOR_ID
        )
    }

    def __init__(
        self, appsync_data=None, doc=None, storage_gateway=None, credentials=None
    ):
        if doc:
            self.username = doc["username"]
            new_doc = {**doc}
            new_doc.pop("display_name", None)
            # Policies must be either empty (for an unprovisioned credential)
            # or passed in as a credentials object from the google callback
            policies = new_doc.get("policies", None)
            if policies is not None and policies != {
                "DATA_TYPE": self.POLICY_DATA_TYPE
            }:
                raise ValueError("policies")

            doc = new_doc
        super().__init__(
            appsync_data=appsync_data, doc=doc, storage_gateway=storage_gateway
        )

        if doc:
            patch = self._credentials_to_patch(credentials)
            patch["deleted"] = False
            patch["provisioned"] = bool(credentials)
            self._patch(**patch)

    @property
    def connector_id(self):
        return self.CONNECTOR_ID

    @connector_id.setter
    def connector_id(self, value):
        pass

    @property
    def token_uri(self) -> str:
        return GOOGLE_TOKEN_URI

    def __repr__(self):
        return "<GoogleDriveUserCredential {}>".format(self.id)
