import typing as t

import marshmallow as ma

from .data_type import Schema, data_type, data_type_schema


@data_type("authentication_timeout#1.0.0")
class AuthenticationTimeout_1_0_0(Schema):
    __doc__ = """
    Error details when a user must reauthenticate an identity
    in order to perform this operation.
    """

    identities = ma.fields.List(
        ma.fields.UUID,
        description="""
        List of identities that would have otherwise been
        authorized except that the authentication has timed out.
        """,
    )
    high_assurance = ma.fields.Boolean(
        description="""
        Boolean flag indicating whether the new authentication
        must be done within the same auth session as the
        application making the request.
        """,
    )


@data_type("authentication_timeout#1.1.0")
class AuthenticationTimeout_1_1_0(AuthenticationTimeout_1_0_0):
    __doc__ = (
        t.cast(str, AuthenticationTimeout_1_0_0.__doc__)
        + """
    Version 1.1.0 adds the require_mfa property.
    """
    )

    require_mfa = ma.fields.Boolean(
        description="""
        Flag indicating that multi-factor authentication is required.
        Only occurs on high assurance storage gateways.
        """
    )


AuthenticationTimeout = data_type_schema.AuthenticationTimeout
