import uuid

import marshmallow as ma

from .data_type import Schema, data_type, data_type_schema


@data_type("endpoint_subscription#1.0.0")
class EndpointSubscription_1_0_0(Schema):
    """
    Endpoint subscription
    """

    subscription_id = ma.fields.String(
        required=True,
        allow_none=True,
        description="""
        Either the id of a Globus subscription or the special value
        "DEFAULT" if the caller has only one subscription associated with
        their identity set.
        """,
    )

    @ma.validates("subscription_id")
    def validate_subscription_id(self, data, **kwargs):
        if data:
            if data == "DEFAULT":
                return data
            else:
                try:
                    return uuid.UUID(data)
                except Exception:
                    raise ma.ValidationError('Value must be a UUID or "DEFAULT"')


EndpointSubscription = data_type_schema.EndpointSubscription
