import marshmallow as ma

from .data_type import Schema, data_type, data_type_schema


class MissingRoleEntrySchema(ma.Schema):
    """
    Missing required role details.
    """

    role = ma.fields.String(
        required=True,
        validate=[
            ma.validate.OneOf(
                [
                    "owner",
                    "administrator",
                    "access_manager",
                    "activity_manager",
                    "activity_monitor",
                    "access_monitor",
                ]
            )
        ],
    )
    collection = ma.fields.UUID(
        description="""
        The collection which the role must apply to. If omitted, the role
        must apply to an endpoint.
        """
    )


@data_type("missing_required_role#1.0.0")
class MissingRequiredRole_1_0_0(Schema):
    """
    Error details when a user has authenticated but lacks a role to be able to
    perform the requested operation.
    """

    roles = ma.fields.List(
        ma.fields.Nested(MissingRoleEntrySchema),
        description="List of roles authorized to perform this operation",
    )


MissingRequiredRole = data_type_schema.MissingRequiredRole
