from ..api import (
    collection_policy,
    data_type_schema,
    storage_gateway_policy,
    user_credential_policy,
)
from .s3 import (
    S3CollectionPolicies_1_0_0,
    S3StoragePolicies_1_0_0,
    S3UserCredentialPolicies_1_0_0,
)

ACTIVESCALE_CONNECTOR_ID = "7251f6c8-93c9-11eb-95ba-12704e0d6a4d"


@storage_gateway_policy(
    S3StoragePolicies_1_0_0._DATA_TYPE,
    register_data_type=False,
    schema_base_name="ActiveScaleStoragePolicies",
)
class ActiveScaleStoragePolicies_1_0_0(S3StoragePolicies_1_0_0):
    """
    Connector-specific storage gateway policies for the ActiveScale connector.
    These are identical to s3 connector's storage gateway policies.
    """

    connector_id = ACTIVESCALE_CONNECTOR_ID


@collection_policy(
    S3CollectionPolicies_1_0_0._DATA_TYPE,
    register_data_type=False,
    schema_base_name="ActiveScaleCollectionPolicies",
)
class ActiveScaleCollectionPolicies_1_0_0(S3CollectionPolicies_1_0_0):
    """
    Connector-specific collection policies for the ActiveScale connector.
    These are identical to s3 connector's collection policies.
    """

    connector_id = ACTIVESCALE_CONNECTOR_ID


@user_credential_policy(
    S3UserCredentialPolicies_1_0_0._DATA_TYPE,
    register_data_type=False,
    schema_base_name="ActiveScaleUserCredentialPolicies",
)
class ActiveScaleUserCredentialPolicies_1_0_0(S3UserCredentialPolicies_1_0_0):
    """
    Connector-specific user credential policies for the ActiveScale connector.
    These are identical to s3 connector's user credential policies.
    """

    connector_id = ACTIVESCALE_CONNECTOR_ID


ActiveScaleCollectionPolicies = data_type_schema.ActiveScaleCollectionPolicies
ActiveScaleStoragePolicies = data_type_schema.ActiveScaleStoragePolicies
ActiveScaleUserCredentialPolicies = data_type_schema.ActiveScaleUserCredentialPolicies
