import marshmallow as ma

from .common_collection_schema import CommonCollectionSchema


class MappedCollectionCommonSchema(CommonCollectionSchema):
    """
    Transfer's view of a mapped collection
    """

    DATA_TYPE = ma.fields.String(default="endpoint")
    public = ma.fields.Boolean(default=True)
    myproxy_server = ma.fields.Constant("myproxy.globusonline.org")
    disable_anonymous_writes = ma.fields.Boolean()
    s3_requester_pays = ma.fields.Boolean(data_key="requester_pays")
    acl_expiration_mins = ma.fields.Int(
        dump_default=None,
        data_key="acl_max_expiration_period_mins",
    )


class MappedCollectionUpdateSchema(MappedCollectionCommonSchema):
    last_accessed_time = ma.fields.DateTime()


class MappedCollectionCreateSchema(MappedCollectionCommonSchema):
    gcs_private_uuid = ma.fields.UUID()
    gcs_private_parent_endpoint_id = ma.fields.UUID()


mapped_collection_create_schema = MappedCollectionCreateSchema()
mapped_collection_update_schema = MappedCollectionUpdateSchema()
