from timeit import default_timer as timer


class ServerTiming:
    def __init__(self):
        self.in_progress = dict()
        self.timing_data = dict()

    def start(self, metric):
        self.in_progress.pop(metric, None)

        start_time = timer()
        self.in_progress.update({metric: start_time})

    def finish(self, metric):
        finish_time = timer()
        start_time = self.in_progress.get(metric)

        if metric is None:
            return

        elapsed_time_ms = round(((finish_time - start_time) * 1000), 2)

        if metric in self.timing_data:
            elapsed_time_ms += self.timing_data[metric]

        self.timing_data.update({metric: elapsed_time_ms})

    def get_timing(self, metric):
        return self.timing_data.get(metric, None)

    def set_timing(self, metric, elapsed_ms):
        self.timing_data.update({metric: elapsed_ms})

    def as_string(self):
        return ",".join(
            ['{}={}; "{}"'.format(k[0], v, k[1]) for k, v in self.timing_data.items()]
        )
