from urllib.parse import parse_qsl, urlencode, urlparse, urlunparse


def update_query_string(url, params, replace=False):
    """
    Given a `url` and a dict of query string `params`, update
    the url's query string to add new params and update existing.
    If `replace=True` any existing query string will be dropped and
    replaced by `params`.
    """
    parsed = urlparse(url)

    if not replace:
        query_string = dict(parse_qsl(parsed.query))
        query_string.update(params)
    else:
        query_string = params

    updated_query_string = urlencode(query_string)

    return urlunparse(
        (
            parsed.scheme,
            parsed.netloc,
            parsed.path,
            parsed.params,
            updated_query_string,
            parsed.fragment,
        )
    )
