from __future__ import absolute_import

import os
import stat

from .log import log


def write_and_link_file(
    name: str, link_name: str, contents, mode: int = stat.S_IRUSR | stat.S_IWUSR
) -> None:
    skip_write = False
    skip_link = False

    name = os.path.normpath(name.replace("//", "/"))
    link_name = os.path.normpath(link_name.replace("//", "/"))

    if name is not None:
        if os.path.exists(name):
            with open(name, "r") as oldfile:
                data = oldfile.read()
                if data == contents:
                    log.debug(
                        "file {} already exists with identical contents".format(name)
                    )
                    skip_write = True
        if not skip_write:
            log.debug("writing file {} with mode {}".format(name, oct(mode)))
            open_flags = os.O_CREAT | os.O_WRONLY | os.O_TRUNC
            with os.fdopen(os.open(name, open_flags, mode), "w") as writable:
                for line in contents:
                    writable.write(line)

    if link_name is not None and os.path.lexists(link_name):
        if os.path.islink(link_name) and os.readlink(link_name) == name:
            skip_link = True
        if not skip_link:
            log.debug("Removing link {}".format(link_name))
            os.remove(link_name)

    if name is not None and link_name is not None and not skip_link:
        log.debug("Symlinking {} -> {}".format(link_name, name))
        os.symlink(name, link_name)
