"""add primary_role flag

Revision ID: fd24f05ab665
Revises: 5a000ca9abac
Create Date: 2019-10-28 13:06:18.722868

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'fd24f05ab665'
down_revision = '5a000ca9abac'
branch_labels = None
depends_on = None


def upgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table=ON")
    op.add_column('role', sa.Column('primary_role', sa.BOOLEAN(), server_default='0', nullable=False))


def downgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table=ON")
    op.rename_table("role", "role_old")
    op.create_table("role",
        sa.Column('id', sa.TEXT(), nullable=False),
        sa.Column('principal_type', sa.Enum('identity', 'group', name='principaltype'), nullable=False),
        sa.Column('identity_id', sa.TEXT(), nullable=False),
        sa.Column('role', sa.Enum('endpoint_administrator', 'endpoint_activity_manager', 'endpoint_activity_monitor', 'collection_administrator', 'collection_activity_manager', 'collection_activity_monitor', 'collection_access_manager', name='roletype'), nullable=False),
        sa.Column('resource', sa.TEXT(), nullable=True),
        sa.PrimaryKeyConstraint('id'),
        sa.ForeignKeyConstraint(['resource'], ['collection.id']),
        sa.UniqueConstraint('principal_type', 'identity_id', 'role', 'resource')
        )
    op.execute(
        """
        INSERT INTO role
        (id, principal_type, identity_id, role, resource)
        SELECT id, principal_type, identity_id, role, resource
        from role_old
        """)
    op.drop_table("role_old")
